# CHANGELOG

## v1.0.0 (2026-03-15)

### Features

- **schema**: add SQLite FTS5 database schema
- **config**: add environment-based configuration
- **backend**: add SQLite FTS5 search and storage engine
- **ingest**: add Markdown parsing and chunking pipeline
- **server**: add MCP server with search and document tools
- **cli**: add command-line interface
- **eval**: add search quality evaluation harness

### Bug Fixes

- **ci**: update semantic-release changelog config for v10 compatibility
